let version = "1.1.1-g411547f-dirty"

let rec realpath path =
  if path = "/" || path = "." then
    path
  else
    begin
      let dirname = Filename.dirname path in
      let new_dirname = realpath dirname in
      let new_path =
        if dirname == new_dirname then path
        else Filename.concat new_dirname (Filename.basename path) in
      let rec follow new_path =
        match
          try Some (Unix.readlink new_path) with Unix.Unix_error _ -> None
        with
        | None -> new_path
        | Some target ->
            let new_path =
              if Filename.is_relative target then
                Filename.concat (Filename.dirname new_path) target
              else
                target in
            follow new_path in
      follow new_path
    end

let path =
  try (Sys.getenv "COCCINELLE_HOME")
  with Not_found->
    let exec_realpath = realpath Sys.executable_name in
    let exec_dir = Filename.dirname exec_realpath in
    if Sys.file_exists (Filename.concat exec_dir "standard.iso") then
      exec_dir
    else
      let libdir =
        Str.global_replace (Str.regexp "[$]{exec_prefix}") exec_dir "/usr/lib64"
      in
      Filename.concat libdir "coccinelle"


let std_iso = ref (Filename.concat path "standard.iso")
let std_h   = ref (Filename.concat path "standard.h")

let dynlink_is_native = Dynlink.is_native
let get_temp_dir_name = (Filename.get_temp_dir_name ())

let configure_flags = "--build=x86_64-redhat-linux-gnu --host=x86_64-redhat-linux-gnu --program-prefix= --disable-dependency-tracking --prefix=/usr --exec-prefix=/usr --bindir=/usr/bin --sbindir=/usr/sbin --sysconfdir=/etc --datadir=/usr/share --includedir=/usr/include --libdir=/usr/lib64 --libexecdir=/usr/libexec --localstatedir=/var --sharedstatedir=/var/lib --mandir=/usr/share/man --infodir=/usr/share/info --with-python=/usr/bin/python3 --with-menhir=/usr/bin/menhir"
let ocaml_version = "4.14.0"

let python_interpreter = ref "/usr/bin/python3"
